<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Repeat: All</source>
        <translation type="obsolete">Repetir: Todo</translation>
    </message>
    <message>
        <source>Repeat: Track</source>
        <translation type="obsolete">Repetir: Pista</translation>
    </message>
    <message>
        <source>Playing stream.</source>
        <translation type="obsolete">Reproduciendo.</translation>
    </message>
    <message>
        <source>Buffering stream.</source>
        <translation type="obsolete">Cargando reproducción.</translation>
    </message>
    <message>
        <source>Stream paused.</source>
        <translation type="obsolete">Reproducción en pausa.</translation>
    </message>
    <message>
        <source>Output error.</source>
        <translation type="obsolete">Error de salida.</translation>
    </message>
    <message>
        <source>Stream stopped.</source>
        <translation type="obsolete">Reproducción parada.</translation>
    </message>
    <message>
        <source>Finished playing stream.</source>
        <translation type="obsolete">Reproducción finalizada.</translation>
    </message>
    <message>
        <source>Decoder error.</source>
        <translation type="obsolete">Error de decodificación.</translation>
    </message>
    <message>
        <source>Random</source>
        <translation type="obsolete">Aleatório</translation>
    </message>
    <message>
        <source>MonoScope</source>
        <translation type="obsolete">Sinal Mono</translation>
    </message>
    <message>
        <source>StereoScope</source>
        <translation type="obsolete">Sinal Estéreo</translation>
    </message>
    <message>
        <source>Spectrum</source>
        <translation type="obsolete">Espectro</translation>
    </message>
    <message>
        <source>BumpScope</source>
        <translation type="obsolete">Scope aos Saltos</translation>
    </message>
    <message>
        <source>Goom</source>
        <translation type="obsolete">GoOoOoM</translation>
    </message>
    <message>
        <source>Synaesthesia</source>
        <translation type="obsolete">Sinastésia</translation>
    </message>
    <message>
        <source>Gears</source>
        <translation type="obsolete">Carretos</translation>
    </message>
    <message>
        <source>Blank</source>
        <translation type="obsolete">Nada</translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="obsolete">Baixa</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation type="obsolete">Média</translation>
    </message>
    <message>
        <source>High</source>
        <translation type="obsolete">Alta</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation type="obsolete">Perfeita</translation>
    </message>
</context>
<context>
    <name>AllMusic</name>
    <message>
        <source>CD -- none</source>
        <translation type="obsolete">Nenhum CD</translation>
    </message>
    <message>
        <source>All My Music</source>
        <translation type="obsolete">Todas as Músicas</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Desconhecido</translation>
    </message>
</context>
<context>
    <name>BlankFactory</name>
    <message>
        <source>Blank</source>
        <translation type="obsolete">Nada</translation>
    </message>
</context>
<context>
    <name>DatabaseBox</name>
    <message>
        <source>Select music to be played:</source>
        <translation type="obsolete">Seleccione as músicas para ouvir:</translation>
    </message>
    <message>
        <source>Copy To New Playlist</source>
        <translation>Copiar Para Uma Lista Nova </translation>
    </message>
    <message>
        <source>Clear the Active Play Queue</source>
        <translation>Limpar a Lista Actual</translation>
    </message>
    <message>
        <source>Save Back to Playlist Tree</source>
        <translation>Gravar a Lista</translation>
    </message>
    <message>
        <source>Move to Active Play Queue</source>
        <translation>Mover a Lista Actual</translation>
    </message>
    <message>
        <source>Delete This Playlist</source>
        <translation>Apagar esta Lista</translation>
    </message>
    <message>
        <source>Rename This Playlist</source>
        <translation>Mudar o Nome Desta Lista</translation>
    </message>
    <message>
        <source>Active Play Queue</source>
        <translation>Lista Activa</translation>
    </message>
    <message>
        <source>All My Playlists</source>
        <translation>Todas as Listas</translation>
    </message>
    <message>
        <source>All My Music</source>
        <translation>Todas as Músicas</translation>
    </message>
    <message>
        <source>genre</source>
        <translation type="obsolete">género</translation>
    </message>
    <message>
        <source>Blechy Blech Blah</source>
        <translation>Yada Yada</translation>
    </message>
    <message>
        <source>cd</source>
        <translation type="obsolete">cd</translation>
    </message>
    <message>
        <source>All My Music ~ Loading Music Data </source>
        <translation>Todas as Músicas - A ler os Dados</translation>
    </message>
    <message>
        <source>Loading Music Data</source>
        <translation>A Ler os Dados da Música</translation>
    </message>
    <message>
        <source>The theme you are using does not contain a &apos;musictree&apos; element.  Please contact the theme creator and ask if they could please update it.&lt;br&gt;&lt;br&gt;The next screen will be empty.  Escape out of it to return to the menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Couldn&apos;t create CD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Created</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD-RW Blanking Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create Audio CD from Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create MP3 CD from Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear CD-RW Disk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The theme you are using does not contain any info lines in the music element.  Please contact the theme creator and ask if they could please update it.&lt;br&gt;&lt;br&gt;The next screen will be empty.  Escape out of it to return to the menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Album:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Genre: </source>
        <translation type="unfinished">Género:</translation>
    </message>
    <message>
        <source>Compilation Artist:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DefaultRipQuality</name>
    <message>
        <source>Low</source>
        <translation type="obsolete">Baixa</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation type="obsolete">Média</translation>
    </message>
    <message>
        <source>High</source>
        <translation type="obsolete">Alta</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation type="obsolete">Perfeita</translation>
    </message>
</context>
<context>
    <name>EditMetadataDialog</name>
    <message>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DB Statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Various Artists</source>
        <translation type="unfinished">Vários Artistas</translation>
    </message>
    <message>
        <source>Select an Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a Compilation Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select an Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save to Database Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save to File Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save to File and Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit/Do Not Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to save the modified metadata to the file?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GearsFactory</name>
    <message>
        <source>Gears</source>
        <translation type="obsolete">Carretos</translation>
    </message>
</context>
<context>
    <name>MadDecoder</name>
    <message>
        <source>Title</source>
        <translation type="obsolete">Título</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="obsolete">Artista</translation>
    </message>
</context>
<context>
    <name>MonoScopeFactory</name>
    <message>
        <source>MonoScope</source>
        <translation type="obsolete">Sinal Mono</translation>
    </message>
</context>
<context>
    <name>PlayMode</name>
    <message>
        <source>Random</source>
        <translation type="obsolete">Aleatório</translation>
    </message>
</context>
<context>
    <name>PlaybackBox</name>
    <message>
        <source>Shuffle Mode</source>
        <translation type="obsolete">Modo aleatorio</translation>
    </message>
    <message>
        <source>Repeat Mode</source>
        <translation type="obsolete">Modo de repetición</translation>
    </message>
    <message>
        <source>Edit Playlist</source>
        <translation type="obsolete">Editar Lista</translation>
    </message>
    <message>
        <source>Visualize</source>
        <translation type="obsolete">Ver Demo</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation type="obsolete">Puntuación</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="obsolete">Artista</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="obsolete">Título</translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="obsolete">Duración</translation>
    </message>
    <message>
        <source>Repeat: Track</source>
        <translation type="obsolete">Repetir: Pista</translation>
    </message>
    <message>
        <source>Repeat: All</source>
        <translation type="obsolete">Repetir: Tudo</translation>
    </message>
    <message>
        <source>Playing stream.</source>
        <translation type="obsolete">A Tocar.</translation>
    </message>
    <message>
        <source>Buffering stream.</source>
        <translation type="obsolete">A Carregar.</translation>
    </message>
    <message>
        <source>Stream paused.</source>
        <translation type="obsolete">Em Pausa.</translation>
    </message>
    <message>
        <source>Output error.</source>
        <translation type="obsolete">Erro ao tocar.</translation>
    </message>
    <message>
        <source>Stream stopped.</source>
        <translation type="obsolete">Parado.</translation>
    </message>
    <message>
        <source>Finished playing stream.</source>
        <translation type="obsolete">Fim de Música.</translation>
    </message>
    <message>
        <source>Decoder error.</source>
        <translation type="obsolete">Erro de descodificação.</translation>
    </message>
    <message>
        <source>Shuffle: Intelligent</source>
        <translation type="obsolete">Aleat.: Inteligente</translation>
    </message>
    <message>
        <source>Shuffle: Random</source>
        <translation type="obsolete">Aleatorio: Casual</translation>
    </message>
    <message>
        <source>1 Shuffle: Intelligent</source>
        <translation type="obsolete">1 Aleat.: Inteligente</translation>
    </message>
    <message>
        <source>1 Shuffle: Random</source>
        <translation type="obsolete">1 Aleatorio: Casual</translation>
    </message>
    <message>
        <source>1 Shuffle: None</source>
        <translation type="obsolete">1 Aleatório: Não</translation>
    </message>
    <message>
        <source>Shuffle: None</source>
        <translation type="obsolete">Aleatório: Não</translation>
    </message>
    <message>
        <source>2 Repeat: All</source>
        <translation type="obsolete">2 Repetir: Tudo</translation>
    </message>
    <message>
        <source>2 Repeat: Track</source>
        <translation type="obsolete">2 Repetir: Pista</translation>
    </message>
    <message>
        <source>2 Repeat: None</source>
        <translation type="obsolete">2 Repetir: Não</translation>
    </message>
    <message>
        <source>Repeat: None</source>
        <translation type="obsolete">Repetir: Não</translation>
    </message>
    <message>
        <source>3 Edit Playlist</source>
        <translation type="obsolete">3 Editar Lista</translation>
    </message>
    <message>
        <source>4 Visualize</source>
        <translation type="obsolete">4 Ver Demo</translation>
    </message>
    <message>
        <source>1 Shuffle: Smart</source>
        <translation type="obsolete">1 Aleatório: Esperto</translation>
    </message>
    <message>
        <source>Shuffle: Smart</source>
        <translation type="obsolete">Aleatório: Esperto</translation>
    </message>
    <message>
        <source>1 Shuffle: Rand</source>
        <translation type="obsolete">1 Aleatório: Sim</translation>
    </message>
    <message>
        <source>Shuffle: Rand</source>
        <translation type="obsolete">Aleatório: Sim</translation>
    </message>
    <message>
        <source>playlist root</source>
        <translation type="obsolete">Raiz da Lista</translation>
    </message>
    <message>
        <source>kbps</source>
        <translation type="obsolete">Kbps</translation>
    </message>
    <message>
        <source>kHz</source>
        <translation type="obsolete">KHz</translation>
    </message>
    <message>
        <source>ch</source>
        <translation type="obsolete">canais</translation>
    </message>
</context>
<context>
    <name>PlaybackBoxMusic</name>
    <message>
        <source>Edit Playlist</source>
        <translation type="unfinished">Editar Lista</translation>
    </message>
    <message>
        <source>Visualize</source>
        <translation type="unfinished">Ver Demo</translation>
    </message>
    <message>
        <source>3 Edit Playlist</source>
        <translation type="unfinished">3 Editar Lista</translation>
    </message>
    <message>
        <source>4 Visualize</source>
        <translation type="unfinished">4 Ver Demo</translation>
    </message>
    <message>
        <source>1 Shuffle: Smart</source>
        <translation type="unfinished">1 Aleatório: Esperto</translation>
    </message>
    <message>
        <source>Shuffle: Smart</source>
        <translation type="unfinished">Aleatório: Esperto</translation>
    </message>
    <message>
        <source>1 Shuffle: Rand</source>
        <translation type="unfinished">1 Aleatório: Sim</translation>
    </message>
    <message>
        <source>Shuffle: Rand</source>
        <translation type="unfinished">Aleatório: Sim</translation>
    </message>
    <message>
        <source>1 Shuffle: None</source>
        <translation type="unfinished">1 Aleatório: Não</translation>
    </message>
    <message>
        <source>Shuffle: None</source>
        <translation type="unfinished">Aleatório: Não</translation>
    </message>
    <message>
        <source>2 Repeat: All</source>
        <translation type="unfinished">2 Repetir: Tudo</translation>
    </message>
    <message>
        <source>2 Repeat: Track</source>
        <translation type="unfinished">2 Repetir: Pista</translation>
    </message>
    <message>
        <source>Repeat: Track</source>
        <translation type="unfinished">Repetir: Pista</translation>
    </message>
    <message>
        <source>2 Repeat: None</source>
        <translation type="unfinished">2 Repetir: Não</translation>
    </message>
    <message>
        <source>Repeat: None</source>
        <translation type="unfinished">Repetir: Não</translation>
    </message>
    <message>
        <source>playlist root</source>
        <translation type="unfinished">Raiz da Lista</translation>
    </message>
    <message>
        <source>kbps</source>
        <translation type="unfinished">Kbps</translation>
    </message>
    <message>
        <source>kHz</source>
        <translation type="unfinished">KHz</translation>
    </message>
    <message>
        <source>ch</source>
        <translation type="unfinished">canais</translation>
    </message>
    <message>
        <source>Repeat: All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Playing stream.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Buffering stream.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stream paused.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Output error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stream stopped.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Finished playing stream.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decoder error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smart playlists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks by current Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks from current Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks from current Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks from current Year</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlaylistsContainer</name>
    <message>
        <source>All My Playlists</source>
        <translation type="obsolete">Todas as Listas</translation>
    </message>
    <message>
        <source>Active Play Queue</source>
        <translation type="obsolete">Lista Activa</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Searching for music files</source>
        <translation>A procurar ficheiros de música</translation>
    </message>
    <message>
        <source>Updating music database</source>
        <translation>A actualizar a base de dados de músicas</translation>
    </message>
    <message>
        <source>Synaesthesia</source>
        <translation>Sinastésia</translation>
    </message>
    <message>
        <source>Directory to hold music</source>
        <translation>Directoria que contem as músicas</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythMusic needs to have write permission to the directory.</source>
        <translation>Esta directoria tem de existir e o utilizador que corre o MythMúsica tem de ter permissões para a ler.</translation>
    </message>
    <message>
        <source>Audio device</source>
        <translation>Dispositivo Áudio</translation>
    </message>
    <message>
        <source>Audio Device to be used to play.</source>
        <translation type="obsolete">O dispositivo a usar para tocar.</translation>
    </message>
    <message>
        <source>CD device</source>
        <translation>Dispositivo CD-Rom</translation>
    </message>
    <message>
        <source>Synaestesia</source>
        <translation type="obsolete">Sinastésia</translation>
    </message>
    <message>
        <source>MonoScope</source>
        <translation>Sinal Mono</translation>
    </message>
    <message>
        <source>StereoScope</source>
        <translation>Sinal Estéreo</translation>
    </message>
    <message>
        <source>Blank</source>
        <translation>Nada</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Aleatório</translation>
    </message>
    <message>
        <source>Spectrum</source>
        <translation>Espectro</translation>
    </message>
    <message>
        <source>Requires FFTW.</source>
        <translation type="obsolete">Necessita da biblioteca FFTW.</translation>
    </message>
    <message>
        <source>BumpScope</source>
        <translation>Scope aos Saltos</translation>
    </message>
    <message>
        <source>Help Text</source>
        <translation type="obsolete">Sem texto de ajuda</translation>
    </message>
    <message>
        <source>Tree Sorting</source>
        <translation>Ordenação da Árvore</translation>
    </message>
    <message>
        <source>Order in which to sort the Music Selection Tree. Possible values are space-separated list of genre, artist, album, and title OR the keyword &quot;directory&quot; to indicate that the onscreen tree mirrors the actual directory tree.</source>
        <translation type="obsolete">A ordem a ser usada na àrvode de selecção das músicas. Os valores possíveis deverâo ser separados por espaços e incluir da seguinte lista: &quot;genre&quot; (género), &quot;artist&quot; (artista), &quot;album&quot; (àlbum) ou &quot;title&quot; (título). Também pode incluir o valor &quot;directory&quot; para indicar que a àrvore no ecrâ representa a ârvore actual.</translation>
    </message>
    <message>
        <source>Script Path</source>
        <translation>Comando pos-cópia de CD</translation>
    </message>
    <message>
        <source>If present this script will be executed after a CD Rip is completed.</source>
        <translation>Se definido, este comando será executado no final da cópia do CD.</translation>
    </message>
    <message>
        <source>Filename Format</source>
        <translation>Formato do Nome do Ficheiro</translation>
    </message>
    <message>
        <source>Help text here.</source>
        <translation type="obsolete">Sem texto de ajuda.</translation>
    </message>
    <message>
        <source>Ignore ID3 Tags</source>
        <translation>Ignorar Informação ID3</translation>
    </message>
    <message>
        <source>If set, MythMusic will skip checking ID3 tags in files and just try to determine Genre, Artist, Album, and Track number and title from the filename.</source>
        <translation>Se definido, o MythMusic irá saltar a verificação da informação ID3 e determinará o género, artista, àlbum e número de pista a partir do nome do ficheiro.</translation>
    </message>
    <message>
        <source>Automatically lookup CDs</source>
        <translation>Ler Automaticamente o CD</translation>
    </message>
    <message>
        <source>Automatically lookup an audio CD if it is present and show its information in the Music Selection Tree.</source>
        <translation>Ler automaticamente um CD àudio se inserido e mostra a sua informação na àrvore de selecção de músicas.</translation>
    </message>
    <message>
        <source>Use Keyboard/Remote Accelerated Buttons</source>
        <translation>Usar teclas de atalho do teclado ou do comando à distância</translation>
    </message>
    <message>
        <source>If this is not set, you will need to use arrow keys to select and activate various functions.</source>
        <translation>Se estiver inactivo, terá de usar os cursores para selecionar e activar as várias funções.</translation>
    </message>
    <message>
        <source>Paranoia Level</source>
        <translation>Nível de Paranóia</translation>
    </message>
    <message>
        <source>Paranoia level of the CD ripper. Set to faster if you&apos;re not concerned about possible errors in the audio.</source>
        <translation>Nível de paranóia na cópia do CD. Escolha rápido se não estiver preocupado com possíveis erros no àudio.</translation>
    </message>
    <message>
        <source>Automatically eject CDs after ripping</source>
        <translation>Ejectar automáticamente o CD depois da cópia</translation>
    </message>
    <message>
        <source>If set, the CD tray will automatically open after the CD has been ripped.</source>
        <translation>Se activo, o CD será ejectado automaticamente no final da cópia.</translation>
    </message>
    <message>
        <source>Rating Weight</source>
        <translation>Peso da Pontuação</translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to your rating of a given track when ordering a group of songs.</source>
        <translation>A ser usado no modo aleatório inteligente. Este valor afecta o peso dado pela votação de uma determinada pista ao ordenar um grupo de músicas.</translation>
    </message>
    <message>
        <source>Play Count Weight</source>
        <translation>Peso por Audições</translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to how many times a given track has been played when ordering a group of songs.</source>
        <translation>A ser usado no modo aleatório inteligente. Este valor afecta o peso dado pela quantidade de audições de uma determinada pista ao ordenar um grupo de músicas.</translation>
    </message>
    <message>
        <source>Last Play Weight</source>
        <translation>Peso por Antiguidade</translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to how long it has been since a given track was played when ordering a group of songs.</source>
        <translation>A ser usado no modo aleatório inteligente. Este valor afecta o peso dado pelo tempo passado desde que uma determinada pista tocou, ao ordenar um grupo de músicas.</translation>
    </message>
    <message>
        <source>Random Weight</source>
        <translation>Peso Aleatório</translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to good old (peudo-)randomness when ordering a group of songs.</source>
        <translation>A ser usado no modo aleatório inteligente. Este valor afecta o peso dado à ordenação aleatória ao ordenar um grupo de músicas.</translation>
    </message>
    <message>
        <source>Show Song Ratings</source>
        <translation>Mostrar Pontuações</translation>
    </message>
    <message>
        <source>Show song ratings on the playback screen.</source>
        <translation>Mostrar pontuações das músicas no ecrâ ao tocar.</translation>
    </message>
    <message>
        <source>List as Shuffled</source>
        <translation>Mostrar como trocadas</translation>
    </message>
    <message>
        <source>List songs on the playback screen in the order they will be played.</source>
        <translation>Mostrar as músicas pela ordem que vão tocar.</translation>
    </message>
    <message>
        <source>Show entire music tree</source>
        <translation>Mostrar a árvore completa de músicas</translation>
    </message>
    <message>
        <source>If selected, you can navigate your entire music tree from the playing screen.</source>
        <translation>Se activo, poderá navegar por toda a àrvore de músicas no ecrâ principal.</translation>
    </message>
    <message>
        <source>Play mode</source>
        <translation>Modo de Tocamento</translation>
    </message>
    <message>
        <source>Starting shuffle mode for the player.  Can be either normal, random, or intelligent (random).</source>
        <translation>Modo aleatório inicial. Pode ser normal, aleatório ou aleatório inteligente.</translation>
    </message>
    <message>
        <source>Delay before Visualizations start (seconds)</source>
        <translation>Tempo de espera antes de começar a visualização (segundos)</translation>
    </message>
    <message>
        <source>If set to 0, visualizations will never automatically start.</source>
        <translation>Se for 0, as visualizações não começam automaticamente.</translation>
    </message>
    <message>
        <source>Change Visualizer on each song</source>
        <translation>Mudar a visualização a cada música</translation>
    </message>
    <message>
        <source>Change the visualizer when the song change.</source>
        <translation>Muda de visualização quando a música muda.</translation>
    </message>
    <message>
        <source>Width for Visual Scaling</source>
        <translation>Largura da Escala Visual</translation>
    </message>
    <message>
        <source>If set to &quot;2&quot;, visualizations will be scaled in half.  Currently only used by the goom visualization.  Reduces CPU load on slower machines.</source>
        <translation>Se for &quot;2&quot;, as visualizações serão escaladas para metade. Actualmente é usado apenas pela visualização &quot;goom&quot;. Esta opção reduz a carga de CPU para máquinas mais lentas.</translation>
    </message>
    <message>
        <source>Height for Visual Scaling</source>
        <translation>Altura para Escala Visual</translation>
    </message>
    <message>
        <source>Requires SDL.</source>
        <translation type="obsolete">Requere SDL.</translation>
    </message>
    <message>
        <source>Goom</source>
        <translation>GoOoOoM</translation>
    </message>
    <message>
        <source>Gears</source>
        <translation>Carretos</translation>
    </message>
    <message>
        <source>Requires OpenGL and FFTW.</source>
        <translation type="obsolete">Requer OpenGL e FFTW.</translation>
    </message>
    <message>
        <source>Visualizations</source>
        <translation>Visualizações</translation>
    </message>
    <message>
        <source>List of visualizations to use during playback. Possible values are space-separated list of Random, MonoScope, StereoScope, Spectrum, BumpScope, Goom, Synaesthesia, Gears, and Blank</source>
        <translation type="obsolete">Lista de visualizações a usar enquanto toca. Os valores possíveis deverão ser separados por espaços e da seguinte lista: Random, MonoScope, StereoScope, Spectrum, BumpScope, Goom, Synaesthesia, Gears e Blank</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Configurações Gerais</translation>
    </message>
    <message>
        <source>Playback Settings</source>
        <translation>Configurações de Leitura</translation>
    </message>
    <message>
        <source>Visualization Settings</source>
        <translation>Configurações de Visualização</translation>
    </message>
    <message>
        <source>Various Artists</source>
        <translation>Vários Artistas</translation>
    </message>
    <message>
        <source>Ogg Vorbis Audio</source>
        <translation>Áudio Ogg Vorbis</translation>
    </message>
    <message>
        <source>music database</source>
        <translation type="obsolete">Base de Dados de Música</translation>
    </message>
    <message>
        <source>cd ripper</source>
        <translation type="obsolete">cópia de CD</translation>
    </message>
    <message>
        <source>

You have no MythMusic tables in your database.</source>
        <translation type="obsolete">

Não existem dados do MythMusic na base de dados.</translation>
    </message>
    <message>
        <source>OK, I&apos;ll read the documentation</source>
        <translation type="obsolete">Ok, eu leio a documentação</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
    <message>
        <source>FLAC Audio</source>
        <translation>Áudio FLAC</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="obsolete">Título</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="obsolete">Artista</translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="obsolete">Álbum</translation>
    </message>
    <message>
        <source>Year</source>
        <translation type="obsolete">Ano</translation>
    </message>
    <message>
        <source>Track</source>
        <translation type="obsolete">Pista</translation>
    </message>
    <message>
        <source>Genre</source>
        <translation type="obsolete">Género</translation>
    </message>
    <message>
        <source>MPEG Layer 1/2/3 Audio (MAD decoder)</source>
        <translation>Áudio MPEG Layer 1/2/3 (descodificador MAD)</translation>
    </message>
    <message>
        <source>Unknown Artist</source>
        <translation>Artista Desconhecido</translation>
    </message>
    <message>
        <source>Unknown Album</source>
        <translation>Álbum Desconhecido</translation>
    </message>
    <message>
        <source>Unknown Genre</source>
        <translation>Género Desconhecido</translation>
    </message>
    <message>
        <source>CD -- none</source>
        <translation>Nenhum CD</translation>
    </message>
    <message>
        <source>All My Music</source>
        <translation>Todas as Músicas</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
    <message>
        <source>title</source>
        <translation>título</translation>
    </message>
    <message>
        <source>Missing database entry: %1</source>
        <translation>Não existe a entrada %1 na base de dados</translation>
    </message>
    <message>
        <source> ~ </source>
        <translation>-</translation>
    </message>
    <message>
        <source>Ooops</source>
        <translation>OoOoPs</translation>
    </message>
    <message>
        <source>%1 ~ %2</source>
        <translation>%1 - %2</translation>
    </message>
    <message>
        <source>Not Initialized</source>
        <translation>Não Inicializado</translation>
    </message>
    <message>
        <source>oops</source>
        <translation>oOps</translation>
    </message>
    <message>
        <source>,%1</source>
        <translation>, %1</translation>
    </message>
    <message>
        <source>All My Playlists</source>
        <translation>Todas as Listas</translation>
    </message>
    <message>
        <source>Active Play Queue</source>
        <translation>Lista Activa</translation>
    </message>
    <message>
        <source>Active Play Queue (%1)</source>
        <translation>Lista Activa (%1)</translation>
    </message>
    <message>
        <source>Something is Wrong</source>
        <translation>Algo está Errado</translation>
    </message>
    <message>
        <source>CDRom device to be used.</source>
        <translation type="obsolete">O dispositivo CDRom a usar.</translation>
    </message>
    <message>
        <source>Encoding</source>
        <translation>Codificação</translation>
    </message>
    <message>
        <source>Ogg Vorbis</source>
        <translation>Ogg Vorbis</translation>
    </message>
    <message>
        <source>Lame (MP3)</source>
        <translation>Lame (MP3)</translation>
    </message>
    <message>
        <source>Audio encoder to use for CD ripping. Note that the quality level &apos;Perfect&apos; will use the FLAC encoder.</source>
        <translation>O codificador âudio a ser usado para as cópias de CDs. Tenha em atenção que o nível de qualidade &quot;Perfeito&quot; irá selecionar o codificador &quot;FLAC&quot;.</translation>
    </message>
    <message>
        <source>File storage location</source>
        <translation>Localização do repositório de músicas</translation>
    </message>
    <message>
        <source>ARTIST/ALBUM/TRACK-TITLE</source>
        <translation type="obsolete">ARTISTA/ÀLBUM/PISTA-TÍTULO</translation>
    </message>
    <message>
        <source>Defines the location/name for new songs. Valid tokens are: GENRE, ARTIST, ALBUM, TRACK, TITLE, YEAR, / and -. &apos;-&apos; will be replaced by the Token separator</source>
        <translation>Define a localização/nome para as novas músicas. As chaves válidas sâo: GENRE (Género), ARTIST (Artista), ALBUM (Àlbum), TRACK (Pista), TITLE (Título), YEAR (Ano), &apos;/&apos; (separador de directoria) ou &apos;-&apos;. O caractér &apos;-&apos; será substituido pelo valor em &quot;Separador de Campo&quot;</translation>
    </message>
    <message>
        <source>Token separator</source>
        <translation>Separador de Campo</translation>
    </message>
    <message>
        <source> - </source>
        <translation>-</translation>
    </message>
    <message>
        <source>Filename tokens will be separated by this string.</source>
        <translation>Os campos do ficheiro serão separados por este texto.</translation>
    </message>
    <message>
        <source>Replace &apos; &apos; with &apos;_&apos;</source>
        <translation>Substituir espaços por &apos;_&apos;</translation>
    </message>
    <message>
        <source>If set, whitespace characters in filenames will be replaced with underscore characters.</source>
        <translation>Se activo, os espaços existentes no nome do ficheiro serão substituidos pelo caractér &apos;_&apos;.</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>Máximo</translation>
    </message>
    <message>
        <source>Faster</source>
        <translation>Rápido</translation>
    </message>
    <message>
        <source>List of visualizations to use during playback. Possible values are space-separated list of </source>
        <translation>Lista de visualizações a usar quando tocar músicas. Os valores possíveis são </translation>
    </message>
    <message>
        <source>CD Ripper Settings</source>
        <translation>Configurações de Cópia de CD</translation>
    </message>
    <message>
        <source>Directory and filename Format used to grab information if no ID3 information is found.</source>
        <translation>Formato de ficheiro e directoria para obter a informação ID3, se não existir dentro do ficheiro.</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Intelligent</source>
        <translation>Inteligente</translation>
    </message>
    <message>
        <source>Default Rip Quality</source>
        <translation>Qualidade de cópia padrão</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Baixa</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Média</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Perfeita</translation>
    </message>
    <message>
        <source>Default quality for new CD rips.</source>
        <translation>Qualidade padrão para cópias de CD.</translation>
    </message>
    <message>
        <source>Stereo Scope</source>
        <translation type="obsolete">Escopo Estéreo</translation>
    </message>
    <message>
        <source>Mono Scope</source>
        <translation type="obsolete">Escopo Mono</translation>
    </message>
    <message>
        <source>Audio Device used for playback.</source>
        <translation>O dispositivo àudio a usar para tocar.</translation>
    </message>
    <message>
        <source>CDRom device used for ripping/playback.</source>
        <translation>O dispositivo do CDROM a usar para tocar ou copiar.</translation>
    </message>
    <message>
        <source>Visualization requires FFT library</source>
        <translation>Este modo necessita da biblioteca FFT</translation>
    </message>
    <message>
        <source>Did you run configure?</source>
        <translation>Executou o configure?</translation>
    </message>
    <message>
        <source>and</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use variable bitrates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, the MP3 encoder will use variable bitrates (VBR) except for the low quality setting. The Ogg encoder will always use variable bitrates.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AlbumArt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Ripper Settings (part 2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable CD Writing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Requires a SCSI or an IDE-SCSI CD Writer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD-Writer Device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select the SCSI Device for CD Writing.  If your IDE device is not present, try adding hdd(or hdc/hdb)=ide-scsi to your boot options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disk Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>650MB/75min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>700MB/80min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default CD Capacity.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable directories on MP3 Creation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Write Speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>16x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Writer speed. Auto will use the recomended speed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Blanking Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blanking Method. Fast takes 1 minute. Complete can take up to 20 minutes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Recording Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creating CD File System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Burning CD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order in which to sort the Music Tree. Possible values are a space-separated list of genre, splitartist, artist, album, and title OR the keyword &quot;directory&quot; to indicate that the onscreen tree mirrors the filesystem.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD: %1 ~ %2 - %3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Ripper</name>
    <message>
        <source>Please select a quality level and check the album information below:</source>
        <translation>Selecione a qualidade pretendida e confirme os dados do álbum abaixo:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Baixa</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Média</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Perfeita</translation>
    </message>
    <message>
        <source>Artist: </source>
        <translation>Artista:</translation>
    </message>
    <message>
        <source>Album: </source>
        <translation>Álbum:</translation>
    </message>
    <message>
        <source>Import this CD</source>
        <translation>Importar este CD</translation>
    </message>
    <message>
        <source>Importing CD:
</source>
        <translation>A importar o CD:
</translation>
    </message>
    <message>
        <source>Copying from CD:
</source>
        <translation>A copiar do CD:
</translation>
    </message>
    <message>
        <source>Genre: </source>
        <translation>Género:</translation>
    </message>
    <message>
        <source>ripping</source>
        <translation type="obsolete">a copiar</translation>
    </message>
    <message>
        <source>Ripping...</source>
        <translation>A Copiar...</translation>
    </message>
    <message>
        <source>Multi-Artist?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch Titles &amp;&amp; Artists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished">Título</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished">Artista</translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished">Duración</translation>
    </message>
</context>
<context>
    <name>SmartPLCriteriaRow</name>
    <message>
        <source>Select an Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select an Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a Title</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmartPLOrderByDialog</name>
    <message>
        <source>Order By Fields</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2 Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3 Move Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4 Move Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5 Ascending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ascending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>6 Descending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Descending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7 OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmartPLResultViewer</name>
    <message>
        <source>Smart Playlist Result Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished">Artista</translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="unfinished">Álbum</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished">Título</translation>
    </message>
    <message>
        <source>Genre</source>
        <translation type="unfinished">Género</translation>
    </message>
    <message>
        <source>Year</source>
        <translation type="unfinished">Ano</translation>
    </message>
    <message>
        <source>Track No.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmartPlaylistDialog</name>
    <message>
        <source>Smart Playlists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2 New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3 Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4 Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this SmartPlaylist?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmartPlaylistEditor</name>
    <message>
        <source>Smart Playlist Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Any</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Of The Following Conditions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order By:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Matches:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Limit:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smart Playlist Categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this Category?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It will also delete any Smart Playlists belonging to this category.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Spectrum</name>
    <message>
        <source>Visualization requires FFT library</source>
        <translation type="obsolete">Este modo necessita da biblioteca FFT</translation>
    </message>
    <message>
        <source>Did you run configure?</source>
        <translation type="obsolete">Executou o configure?</translation>
    </message>
</context>
<context>
    <name>SpectrumFactory</name>
    <message>
        <source>Spectrum</source>
        <translation type="obsolete">Espectro</translation>
    </message>
</context>
<context>
    <name>StereoScopeFactory</name>
    <message>
        <source>StereoScope</source>
        <translation type="obsolete">Sinal Estéreo</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Please Wait...</source>
        <translation>Aguarde um Momento...</translation>
    </message>
    <message>
        <source>Track Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Album:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Genre:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Year:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Track No.:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rating:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play Count:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Play:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Compilation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VisualizationMode</name>
    <message>
        <source>Random</source>
        <translation type="obsolete">Aleatório</translation>
    </message>
    <message>
        <source>MonoScope</source>
        <translation type="obsolete">Sinal Mono</translation>
    </message>
    <message>
        <source>StereoScope</source>
        <translation type="obsolete">Sinal Estéreo</translation>
    </message>
    <message>
        <source>Spectrum</source>
        <translation type="obsolete">Espectro</translation>
    </message>
    <message>
        <source>BumpScope</source>
        <translation type="obsolete">Scope aos Saltos</translation>
    </message>
    <message>
        <source>Goom</source>
        <translation type="obsolete">GoOoOoM</translation>
    </message>
    <message>
        <source>Synaesthesia</source>
        <translation type="obsolete">Sinastésia</translation>
    </message>
    <message>
        <source>Gears</source>
        <translation type="obsolete">Carretos</translation>
    </message>
    <message>
        <source>Blank</source>
        <translation type="obsolete">Nada</translation>
    </message>
</context>
</TS>
